Class: Organizations::JoinFlow::Result

Inherits:
Struct
  • Object
show all
Defined in:
lib/organizations/join_flow.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#join_requestObject

Returns the value of attribute join_request

Returns:

  • (Object)

    the current value of join_request



64
65
66
# File 'lib/organizations/join_flow.rb', line 64

def join_request
  @join_request
end

#membershipObject

Returns the value of attribute membership

Returns:

  • (Object)

    the current value of membership



64
65
66
# File 'lib/organizations/join_flow.rb', line 64

def membership
  @membership
end

#messageObject

Returns the value of attribute message

Returns:

  • (Object)

    the current value of message



64
65
66
# File 'lib/organizations/join_flow.rb', line 64

def message
  @message
end

#outcomeObject

Returns the value of attribute outcome

Returns:

  • (Object)

    the current value of outcome



64
65
66
# File 'lib/organizations/join_flow.rb', line 64

def outcome
  @outcome
end

#reasonObject

Returns the value of attribute reason

Returns:

  • (Object)

    the current value of reason



64
65
66
# File 'lib/organizations/join_flow.rb', line 64

def reason
  @reason
end

Instance Method Details

#challenge_sent?Boolean

Returns:

  • (Boolean)


66
# File 'lib/organizations/join_flow.rb', line 66

def challenge_sent? = outcome == :challenge_sent

#error?Boolean

Returns:

  • (Boolean)


69
70
# File 'lib/organizations/join_flow.rb', line 69

def error? = outcome == :error
# Anything that should render as a problem state (veto included).

#failed?Boolean

Anything that should render as a problem state (veto included).

Returns:

  • (Boolean)


71
# File 'lib/organizations/join_flow.rb', line 71

def failed? = error? || vetoed?

#member?Boolean

Returns:

  • (Boolean)


65
# File 'lib/organizations/join_flow.rb', line 65

def member? = outcome == :member

#pending?Boolean

Returns:

  • (Boolean)


67
# File 'lib/organizations/join_flow.rb', line 67

def pending? = outcome == :pending

#vetoed?Boolean

Returns:

  • (Boolean)


68
# File 'lib/organizations/join_flow.rb', line 68

def vetoed? = outcome == :vetoed