Class: Organizations::PublicController

Inherits:
Object
  • Object
show all
Includes:
CurrentUserResolution
Defined in:
app/controllers/organizations/public_controller.rb

Overview

Base controller for public routes that don't require authentication. Inherits from the configured public_controller (defaults to ActionController::Base) to avoid inheriting host app filters that might enforce authentication.

Use cases:

  • Invitation acceptance pages (users clicking email links)
  • Any other routes that should work for unauthenticated users

Direct Known Subclasses

PublicInvitationsController