Class: Organizations::JoinFlow::Result
- Inherits:
-
Struct
- Object
- Struct
- Organizations::JoinFlow::Result
- Defined in:
- lib/organizations/join_flow.rb
Instance Attribute Summary collapse
-
#join_request ⇒ Object
Returns the value of attribute join_request.
-
#membership ⇒ Object
Returns the value of attribute membership.
-
#message ⇒ Object
Returns the value of attribute message.
-
#outcome ⇒ Object
Returns the value of attribute outcome.
-
#reason ⇒ Object
Returns the value of attribute reason.
Instance Method Summary collapse
- #challenge_sent? ⇒ Boolean
- #error? ⇒ Boolean
-
#failed? ⇒ Boolean
Anything that should render as a problem state (veto included).
- #member? ⇒ Boolean
- #pending? ⇒ Boolean
- #vetoed? ⇒ Boolean
Instance Attribute Details
#join_request ⇒ Object
Returns the value of attribute join_request
64 65 66 |
# File 'lib/organizations/join_flow.rb', line 64 def join_request @join_request end |
#membership ⇒ Object
Returns the value of attribute membership
64 65 66 |
# File 'lib/organizations/join_flow.rb', line 64 def membership @membership end |
#message ⇒ Object
Returns the value of attribute message
64 65 66 |
# File 'lib/organizations/join_flow.rb', line 64 def @message end |
#outcome ⇒ Object
Returns the value of attribute outcome
64 65 66 |
# File 'lib/organizations/join_flow.rb', line 64 def outcome @outcome end |
#reason ⇒ Object
Returns the value of attribute reason
64 65 66 |
# File 'lib/organizations/join_flow.rb', line 64 def reason @reason end |
Instance Method Details
#challenge_sent? ⇒ Boolean
66 |
# File 'lib/organizations/join_flow.rb', line 66 def challenge_sent? = outcome == :challenge_sent |
#error? ⇒ Boolean
69 70 |
# File 'lib/organizations/join_flow.rb', line 69 def error? = outcome == :error # Anything that should render as a problem state (veto included). |
#failed? ⇒ Boolean
Anything that should render as a problem state (veto included).
71 |
# File 'lib/organizations/join_flow.rb', line 71 def failed? = error? || vetoed? |
#member? ⇒ Boolean
65 |
# File 'lib/organizations/join_flow.rb', line 65 def member? = outcome == :member |
#pending? ⇒ Boolean
67 |
# File 'lib/organizations/join_flow.rb', line 67 def pending? = outcome == :pending |
#vetoed? ⇒ Boolean
68 |
# File 'lib/organizations/join_flow.rb', line 68 def vetoed? = outcome == :vetoed |